@@ -3,7 +3,7 @@ use std::{
     path::{Path, PathBuf},
 };
 use swc_common::{FileName, Span};
-use swc_css_ast::{Number, Str, Stylesheet, UrlValueRaw};
+use swc_css_ast::{HexColor, ImportantFlag, Number, Str, Stylesheet, UrlValueRaw};
 use swc_css_codegen::{
     writer::basic::{BasicCssWriter, BasicCssWriterConfig},
     CodeGenerator, CodegenConfig, Emit,
@@ -101,6 +101,13 @@ impl VisitMut for NormalizeTest {
         *n = Default::default()
     }
 
+    fn visit_mut_important_flag(&mut self, n: &mut ImportantFlag) {
+        n.visit_mut_children_with(self);
+
+        n.value.value = n.value.value.to_lowercase().into();
+        n.value.raw = n.value.raw.to_lowercase().into();
+    }
+
     fn visit_mut_url_value_raw(&mut self, n: &mut UrlValueRaw) {
         n.visit_mut_children_with(self);
 
@@ -120,6 +127,13 @@ impl VisitMut for NormalizeTest {
 
         n.raw = "".into();
     }
+
+    fn visit_mut_hex_color(&mut self, n: &mut HexColor) {
+        n.visit_mut_children_with(self);
+
+        n.value = "fff".into();
+        n.raw = "fff".into();
+    }
 }
 
 #[testing::fixture("tests/fixture/**/input.css")]
